@@ -12,6 +12,7 @@ from schema import Schema, Use, And, SchemaError
 from schema import Optional as SOptional
 from pandas import DataFrame as PDataFrame
 
+from .valid_job import ValidJob
 from .executed import InvalidJob, ExecutedJob
 from ..models.dataframe_from import VALID_INPUT_FORMATS, df_from
 from ..models.dataframe_to import df_to
@@ -50,7 +51,7 @@ class FormatJob:
         except SchemaError as e:
             return InvalidJob(f"Invalid Schema: {message(e)}")
 
-class ValidFormatJob:
+class ValidFormatJob(ValidJob):
 
     def __init__(self, t):
         self.input_paths: List[str] = t.input_paths
@@ -138,7 +139,7 @@ class ValidFormatJob:
             def repartition_and_write(df: DataFrame) -> Result[ExecutedJob, InvalidJob]:
                 pc = self.partition_columns
                 df.groupby(pc).apply(write_partitioned, meta=str).compute()
-                return Success(ExecutedJob("GOOD"))
+                return Success(ExecutedJob(f"Repartitioned dataframe according to columns {self.partition_columns} and output to {self.output_path}"))
             
             check = self.check_columns(df, self.partition_columns)
             return flatten(check.map(lambda b: repartition_and_write(b)))
