@@ -11,7 +11,7 @@ from dask import dataframe as dd
 
 from mason_dask.utils.cluster_spec import ClusterSpec
 
-TMP = "../tmp/"
+TMP = from_root("/.tmp/")
 TEST_DATA = from_root("/test/data/test_data.csv")
 
 @pytest.fixture(scope="module")
@@ -108,7 +108,7 @@ def test_csv(client):
 
     job = FormatJob(spec).validate()
     assert(isinstance(job, ValidFormatJob))
-    job.run(cluster_spec)
+    result = job.run(cluster_spec)
 
     parts = ["0.part", '1.part']
     assert(sorted(listdir(TMP + "csv/")) == parts)
@@ -191,7 +191,7 @@ def test_parquet(client):
     job.run(cluster_spec)
 
     parts = ["part.0.parquet", 'part.1.parquet']
-    assert(list(filter(lambda f: f.endswith(".parquet"),listdir(TMP + "parquet/"))) == parts)
+    assert(sorted(list(filter(lambda f: f.endswith(".parquet"),listdir(TMP + "parquet/")))) == parts)
     for p in parts:
         df = dd.read_parquet(TMP + f"/parquet/{p}").compute()
         assert(df.shape[0] == 2)
@@ -205,7 +205,7 @@ def test_parquet(client):
     job.run(cluster_spec)
 
     prts = [789.0, 123.0]
-    assert(list(filter(lambda f: f.endswith(".parquet"), listdir(TMP + "parquet/"))) == ["part.0.parquet", "part.1.parquet"])
+    assert(sorted(list(filter(lambda f: f.endswith(".parquet"), listdir(TMP + "parquet/")))) == ["part.0.parquet", "part.1.parquet"])
 
     for prt in prts:
         df = dd.read_parquet(TMP + f"parquet/col_a={prt}/part.0.parquet").compute()
